package com.sun.tools.javac.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "22" },
            { "jdk", "22" },
            { "release", "22" },
        };
    }
}
